@@ -21,7 +21,7 @@ get_asp_ratio <- function(x, is.projected = NA, width=700, height=700, res=100)
 		asp <- print(x, return.asp = TRUE)
 		dev.off()
 	} else {
-	    if (inherits(x, c("Spatial", "Raster", "sf"))) {
+	    if (inherits(x, c("Spatial", "Raster", "sf", "sfc"))) {
 	        bbx <- bb(x)
 	        if (is.na(is.projected)) is.projected <- is_projected(x)
 	    } else {
